@@ -318,6 +318,30 @@ def test_nworkers_changed():
     assert c.nworkers_changed(1, 2, 3) == 3
 
 
+def test_statsd_host():
+    c = config.Config()
+    assert c.statsd_host is None
+    c.set("statsd_host", "localhost")
+    assert c.statsd_host == ("localhost", 8125)
+    c.set("statsd_host", "statsd:7777")
+    assert c.statsd_host == ("statsd", 7777)
+    c.set("statsd_host", "unix:///path/to.sock")
+    assert c.statsd_host == "/path/to.sock"
+    pytest.raises(TypeError, c.set, "statsd_host", 666)
+    pytest.raises(TypeError, c.set, "statsd_host", "host:string")
+
+
+def test_statsd_host_with_unix_as_hostname():
+    # This is a regression test for major release 20. After this release
+    # we should consider modifying the behavior of util.parse_address to
+    # simplify gunicorn's code
+    c = config.Config()
+    c.set("statsd_host", "unix:7777")
+    assert c.statsd_host == ("unix", 7777)
+    c.set("statsd_host", "unix://some.socket")
+    assert c.statsd_host == "some.socket"
+
+
 def test_statsd_changes_logger():
     c = config.Config()
     assert c.logger_class == glogging.Logger
@@ -429,41 +453,6 @@ def test_umask_config(options, expected):
     assert app.cfg.umask == expected
 
 
-@pytest.mark.parametrize("options, expected", [
-    (["--ssl-version", "SSLv23"], 2),
-    (["--ssl-version", "TLSv1"], 3),
-    (["--ssl-version", "2"], 2),
-    (["--ssl-version", "3"], 3),
-])
-def test_ssl_version_named_constants_python3(options, expected):
-    _test_ssl_version(options, expected)
-
-
-@pytest.mark.skipif(sys.version_info < (3, 6),
-    reason="requires python3.6+")
-@pytest.mark.parametrize("options, expected", [
-    (["--ssl-version", "TLS"], 2),
-    (["--ssl-version", "TLSv1_1"], 4),
-    (["--ssl-version", "TLSv1_2"], 5),
-    (["--ssl-version", "TLS_SERVER"], 17),
-])
-def test_ssl_version_named_constants_python36(options, expected):
-    _test_ssl_version(options, expected)
-
-
-@pytest.mark.parametrize("ssl_version", [
-    "FOO",
-    "-99",
-    "99991234"
-])
-def test_ssl_version_bad(ssl_version):
-    c = config.Config()
-    with pytest.raises(ValueError) as exc:
-        c.set("ssl_version", ssl_version)
-    assert 'Valid options' in str(exc.value)
-    assert "TLSv" in str(exc.value)
-
-
 def _test_ssl_version(options, expected):
     cmdline = ["prog_name"]
     cmdline.extend(options)
